@@ -10,8 +10,12 @@
         openerRef = windowRef.parent;
         windowName = windowRef.name;
         widgetName = windowName.replace(/^(change|add|delete|lookup)_/, '');
+        if (typeof(openerRef.id_to_windowname) === 'function') {
+            // django < 3.1 compatibility
+            widgetName = openerRef.id_to_windowname(widgetName);
+        }
         windowRef = {
-            name: openerRef.id_to_windowname(widgetName),
+            name: widgetName,
             close: function() {
                 openerRef.dismissRelatedObjectModal();
             }
